# E075: indexing requires an expression

```config-for-examples
{
  "globals": {
    "friends": true
  }
}
```

The syntax for indexing is `expr1[expr2]`. It is an error to omit the expression
between `[` and `]`:

    let colorToHexCode = {
      red:   '#ff0000',
      green: '#00ff00',
      blue:  '#0000ff',
    };
    let colorName = prompt();
    document.body.style.color = colorToHexCode[];

    let newFriends = friends[];
    newFriends.push("Alice");
    console.log("before:", friends, "after:", newFriends);

To fix this error, write an expression between `[` and `]`:

    let colorToHexCode = {
      red:   '#ff0000',
      green: '#00ff00',
      blue:  '#0000ff',
    };
    let colorName = prompt();
    document.body.style.color = colorToHexCode[colorName];

Alternatively, to copy an array, create a new array and spread the old array
into the new array:

    let newFriends = [...friends];
    newFriends.push("Alice");
    console.log("before:", friends, "after:", newFriends);

